@@ -7,6 +7,7 @@
 #include "kitathreadview.h"
 #include "kitasubjectview.h"
 #include "kitaboardview.h"
+#include "kitacacheinfo.h"
 
 #include <qdragobject.h>
 #include <kprinter.h>
@@ -27,6 +28,7 @@
 #include <kurl.h>
 #include <kurlrequesterdlg.h>
 #include <krun.h>
+#include <kstandarddirs.h>
 
 #include <kedittoolbar.h>
 
@@ -48,28 +50,35 @@ Kita::Kita()
   // then, setup our actions
   setupActions();
 
+  // load cache
+  loadCache();
+  
   // and a status bar
   statusBar()->show();
-
+  
   // apply the saved mainwindow settings, if any, and ask the mainwindow
   // to automatically save settings if changed: window size, toolbar
   // position, icon size, etc.
   setAutoSaveSettings();
 
   // allow the view to change the statusbar and caption
-  connect(m_threadview, SIGNAL(signalChangeStatusbar(const QString&)),
+  connect(m_threadView, SIGNAL(signalChangeStatusbar(const QString&)),
           this,   SLOT(changeStatusbar(const QString&)));
   connect(m_boardView, SIGNAL(signalLoadBoard(const KURL&, const QString&)),
           m_subjectView, SLOT(slotLoadBoard(const KURL&, const QString&)));
-  connect(m_subjectView, SIGNAL(signalShowThread(const KURL&, const KURL&, const QString&)),
-          m_threadview, SLOT(slotShowThread(const KURL&, const KURL&, const QString&)));
+  connect(m_subjectView, SIGNAL(signalShowThread(const Kita2ch::Board&, const Kita2ch::Thread&)),
+          m_threadView, SLOT(slotShowThread(const Kita2ch::Board&, const Kita2ch::Thread&)));
   //    connect(m_view, SIGNAL(signalChangeCaption(const QString&)),
   //            this,   SLOT(changeCaption(const QString&)));
+  connect(m_threadView, SIGNAL(setVestedNum(const KURL&, int)), SLOT(slotSetVestedNum(const KURL&, int)));
   m_boardView->loadBoardList();
 }
 
+
 Kita::~Kita()
-{}
+{
+  saveCache();
+}
 
 void Kita::load(const KURL& url)
 {
@@ -278,6 +287,10 @@ void Kita::optionsPreferences()
 {
   // popup some sort of preference dialog, here
   KitaPreferences dlg;
+  
+  connect(&dlg, SIGNAL(signalFontChanged(QFont&)), m_threadView, SLOT(slotFontChanged(QFont&)));
+  connect(&dlg, SIGNAL(signalFontChanged(QFont&)), m_subjectView, SLOT(slotFontChanged(QFont&)));
+  connect(&dlg, SIGNAL(signalFontChanged(QFont&)), m_boardView, SLOT(slotFontChanged(QFont&)));
   if (dlg.exec()) {
     // redo your settings
   }
@@ -299,11 +312,11 @@ void Kita::setupView()
 {
   KDockWidget* mainDock;
   mainDock = createDockWidget("main", 0L, 0L, i18n("main"));
-  m_threadview = new KitaThreadView(mainDock);
-  mainDock->setWidget(m_threadview);
+  m_threadView = new KitaThreadView(mainDock);
+  mainDock->setWidget(m_threadView);
   mainDock->setDockSite(KDockWidget::DockFullSite);
   mainDock->setEnableDocking(KDockWidget::DockNone);
-    connect( m_threadview, SIGNAL( openURLRequest(const KURL&, const KParts::URLArgs&) ),
+    connect( m_threadView, SIGNAL( openURLRequest(const KURL&, const KParts::URLArgs&) ),
 		    	   SLOT( slotOpenURLRequest(const KURL&, const KParts::URLArgs&) ) );
 
   KDockWidget* subjectDock;
@@ -329,4 +342,32 @@ void Kita::slotOpenURLRequest(const KURL& url, const KParts::URLArgs&)
 {
   new KRun(url);
 }
+
+void Kita::slotSetVestedNum(const KURL& threadURL, int resCount)
+{
+  KitaCacheInfo::getInstance()->setVestedNum(threadURL, resCount);
+}
+
+void Kita::loadCache()
+{
+  KitaCacheInfo* cache = KitaCacheInfo::getInstance();
+  QString cacheConfigPath = locateLocal("appdata", "cache");
+  QFile file(cacheConfigPath);
+  if( file.open(IO_ReadOnly) ) {
+    QDataStream stream(&file);
+    stream >> *cache;
+  }
+}
+
+void Kita::saveCache()
+{
+  KitaCacheInfo* cache = KitaCacheInfo::getInstance();
+  QString cacheConfigPath = locateLocal("appdata", "cache");
+  QFile file(cacheConfigPath);
+  if( file.open(IO_WriteOnly) ) {
+    QDataStream stream(&file);
+    stream << *cache;
+  }
+}
+
 #include "kita.moc"
