@@ -59,7 +59,6 @@ protected:
     virtual void dragEnterEvent(QDragEnterEvent *event);
     virtual void dropEvent(QDropEvent *event);
 
-protected:
     /**
      * This function is called when it is time for the app to save its
      * properties for session management purposes.
@@ -73,7 +72,6 @@ protected:
      */
     void readProperties(KConfig *);
 
-
 private slots:
     void fileNew();
     void fileOpen();
@@ -90,20 +88,22 @@ private slots:
     void changeStatusbar(const QString& text);
     void changeCaption(const QString& text);
     void slotOpenURLRequest(const KURL& url, const KParts::URLArgs&);
+    void slotSetVestedNum(const KURL& threadURL, int resCount);
 
 private:
-    void setupAccel();
-    void setupActions();
-    void setupView();
-
-private:
-    KitaThreadView *m_threadview;
+    KitaThreadView *m_threadView;
     KitaBoardView* m_boardView;
     KitaSubjectView* m_subjectView;
 
     KPrinter   *m_printer;
     KToggleAction *m_toolbarAction;
     KToggleAction *m_statusbarAction;
+
+    void setupAccel();
+    void setupActions();
+    void setupView();
+    void loadCache();
+    void saveCache();
 };
 
 #endif // _KITA_H_
