@@ -27,6 +27,8 @@
  
 #include "kitasubjectview.h"
 #include "kita.h"
+#include "kitacacheinfo.h"
+#include "part/kita2ch.h"
 
 enum SubjectViewRows {
   Row_ID,
@@ -34,6 +36,7 @@ enum SubjectViewRows {
   Row_Subject,
   Row_ResNum,
   Row_Vested,
+  Row_Unread,
   Row_DatName,
 };
 
@@ -50,6 +53,7 @@ KitaSubjectView::KitaSubjectView(QWidget *parent, const char *name)
   subjectList->addColumn(i18n("Title"));
   subjectList->addColumn(i18n("ResNum"));
   subjectList->addColumn(i18n("Vested"));
+  subjectList->addColumn(i18n("Unread"));
   subjectList->addColumn(i18n("Dat"));
 
   subjectList->setColumnWidth(Row_Subject, 400);
@@ -73,9 +77,9 @@ void KitaSubjectView::reloadSubject()
 void KitaSubjectView::loadThread(QListViewItem* item)
 {
   QString datName = item->text(Row_DatName);
-  KURL datURL = m_boardURL;
+  KURL datURL = m_board.url();
   datURL.addPath("/dat/" + datName);
-  emit signalShowThread(datURL, m_boardURL, m_boardName);
+  emit signalShowThread(m_board, Kita2ch::Thread(datURL));
 }
 
 void KitaSubjectView::slotLoadBoard(const KURL& url, const QString& boardName)
@@ -87,41 +91,27 @@ void KitaSubjectView::slotLoadBoard(const KURL& url, const QString& boardName)
     m_prevquery = "";
   }
 
-  m_boardURL = url;
-  m_boardName = boardName;
+  m_board = Kita2ch::Board(url, boardName);
+  m_board.refreshChildList();
 
-  KIO::SlaveConfig::self()->setConfigData("http", url.host() , "UserAgent", "Monazilla/1.00 (test)");
-
-  QString tmpFile;
-  KURL subjectURL = KURL(url, "subject.txt");
-  if(KIO::NetAccess::download(subjectURL, tmpFile)) {
-    QIODevice* tmpDevice = KFilterDev::deviceForFile(tmpFile, "application/x-gzip");
-    tmpDevice->open(IO_ReadOnly);
-
-    QTextStream stream(tmpDevice);
-    stream.setCodec(QTextCodec::codecForName("Shift_JIS"));
-
-    // clear list
-    subjectList->clear();
-
-    // parse subject.txt(only one format...)
-    QRegExp regexp("(\\d+\\.dat)<>(.*)\\((\\d+)\\)");
-    QString line;
-    int row=1;
-
-    while((line = stream.readLine()) != QString::null) {
-      int pos = regexp.search(line);
-      if(pos != -1) {
-        QString fname = regexp.cap(1);
-        QString subject = regexp.cap(2);
-        QString num = regexp.cap(3);
-
-        new KListViewItem(subjectList, QString("%1").arg(row, 4), "", subject, QString("%1").arg(num, 4), "", fname);
-        row++;
-      }
-    }
-
-    KIO::NetAccess::removeTempFile(tmpFile);
+  KitaCacheInfo* cache = KitaCacheInfo::getInstance();  
+  QPtrList<Kita2ch::Thread> threadList = m_board.getThreadList();
+  
+  // clear list
+  subjectList->clear();
+  
+  for(int i=0; i<threadList.count(); i++) {
+    Kita2ch::Thread* thread = threadList.at(i);
+    
+    int vested = cache->getVestedNum(thread->datURL());
+    new KListViewItem(subjectList,
+                      QString("%1").arg(i+1, 4),
+                      "",
+                      thread->name(),
+                      QString("%1").arg(thread->resNum(), 4),
+                      vested > 0 ? QString::number(vested) : "",
+                      vested > 0 ? QString::number(thread->resNum() - vested) : "",
+                      thread->datURL().fileName());
   }
 
   if( HideButton->isOn() ) {
@@ -218,3 +208,7 @@ void KitaSubjectView::slotHideButton(bool on)
     ++listIt;
   }
 }
+
+void KitaSubjectView::slotFontChanged(QFont& font)
+{
+}
