@@ -14,6 +14,7 @@
 #include <qwidget.h>
 #include <kurl.h>
 #include "kitasubjectviewbase.h"
+#include "part/kita2ch.h"
 
 class Kita;
 class KListViewItem;
@@ -29,26 +30,31 @@ class KitaSubjectView : public KitaSubjectViewBase
 public:
   KitaSubjectView(QWidget *parent, const char *name=0);
   ~KitaSubjectView();
+
 public slots:
   void reloadSubject();
   void loadThread(QListViewItem* item);
   void slotLoadBoard(const KURL& url, const QString& boardName);
   void slotHideButton(bool on);
+  void slotFontChanged(QFont& font);
+
 private: // Private attributes
-  KURL m_boardURL;
-  QString m_boardName;
+  Kita2ch::Board m_board;
+  QStringList m_prevquery;
+  int m_nextHitIndex;
+  QValueList<KListViewItem*> m_hitList;
+  
   void insertSearchCombo();
   QStringList parseSearchQuery(const QString &input);
   void searchNext(const QStringList &input);
-  QStringList m_prevquery;
   void searchAll(const QStringList &query);
-  int m_nextHitIndex;
-  QValueList<KListViewItem*> m_hitList;
-signals:
-  void signalShowThread(const KURL& datURL, const KURL& boardURL, const QString& boardName);
-  void signalSubjectListClicked(QListViewItem* item);
+
 private slots:
   void slotSearchButton();
+
+signals:
+  void signalShowThread(const Kita2ch::Board& board, const Kita2ch::Thread& thread);
+  void signalSubjectListClicked(QListViewItem* item);
 };
 
 #endif
