@@ -43,24 +43,24 @@
 
 #include "kitathreadview.h"
 #include "kitawritedialog.h"
+#include "../kitacacheinfo.h"
+#include "kita2ch.h"
 
 #include <qmessagebox.h>
 
-static QString linkURL(QString);
-
 KitaThreadView::KitaThreadView(QWidget *parent, const char *name)
     : KitaThreadViewBase(parent, name)
     , m_parent( parent )
     , m_currentJob( 0 )
     , m_labelMaxLength( 60 )
 {
-  threadPart = new KHTMLPart(threadFrame);
+  m_threadPart = new KHTMLPart(threadFrame);
   QHBoxLayout* aLayout = new QHBoxLayout(threadFrame);
-  aLayout->addWidget(threadPart->view());
+  aLayout->addWidget(m_threadPart->view());
 
   {
-    threadPart->setStandardFont("Gothic [Mona]");
-    threadPart->setZoomFactor(120); // 12px;    
+    m_threadPart->setStandardFont("Gothic [Mona]");
+    m_threadPart->setZoomFactor(120); // 12px;    
 #if 0 // provides you with mona font info.
     QString info;
     info +=  view()->font().family();
@@ -73,24 +73,26 @@ KitaThreadView::KitaThreadView(QWidget *parent, const char *name)
   {
     SearchButton->setPixmap( SmallIcon("find") );
     HighLightButton->setPixmap( SmallIcon("idea") );
+    ReloadButton->setPixmap( SmallIcon("reload") );
   }
 
   setAcceptDrops( true ); // DND Drop eneble: 2nd stage. - enable on "KitaThreadView" widget and disable on the others(child widgets of "KitaThreadView").
   threadFrame->setAcceptDrops( false ); // don't treat Drop event on child.
-  threadPart->view()->setAcceptDrops( false ); // don't treat Drop event on child.
+  m_threadPart->view()->setAcceptDrops( false ); // don't treat Drop event on child.
 
-  threadPart->enableMetaRefresh( false ); //disable <meta refresh="...">
+  m_threadPart->enableMetaRefresh( false ); //disable <meta refresh="...">
 
 
   connect( writeButton, SIGNAL(clicked()), SLOT(slotWriteButtonClicked()));
-  connect( threadPart, SIGNAL( nodeActivated(const DOM::Node &) ), SLOT( slotDOMNodeActivated(const DOM::Node &) ) );
-  connect( threadPart, SIGNAL( onURL(const QString&) ), SLOT( slotOnURL(const QString&) ) );
+  connect( m_threadPart, SIGNAL( nodeActivated(const DOM::Node &) ), SLOT( slotDOMNodeActivated(const DOM::Node &) ) );
+  connect( m_threadPart, SIGNAL( onURL(const QString&) ), SLOT( slotOnURL(const QString&) ) );
   connect( SearchButton, SIGNAL( clicked() ), SLOT( slotSearchButton() ) );
   connect( SearchCombo, SIGNAL( activated(int) ), SLOT( slotSearchButton() ) );
   connect( HighLightButton, SIGNAL( toggled(bool) ), SLOT( slotHighLightenButton(bool) ) );
   connect( GobackAnchorButton, SIGNAL( clicked() ), SLOT( gobackAnchor() ) );
+  connect( ReloadButton, SIGNAL( clicked() ), SLOT( slotReloadButton() ) );
 
-  KParts::BrowserExtension * ext = threadPart->browserExtension();
+  KParts::BrowserExtension * ext = m_threadPart->browserExtension();
   connect( ext, SIGNAL( openURLRequest(const KURL&, const KParts::URLArgs&) ),
                  SLOT( slotOpenURLRequest(const KURL&, const KParts::URLArgs&) ) );
       		//SIGNAL( openURLRequest(const KURL&, const KParts::URLArgs&) ) );
@@ -110,7 +112,7 @@ KitaThreadView::~KitaThreadView() {}
 
 QString KitaThreadView::threadSubject() const
 {
-  return m_subject;
+  return m_thread.name();
 }
 
 void KitaThreadView::slotDOMNodeActivated(const DOM::Node &node)
@@ -125,7 +127,8 @@ void KitaThreadView::slotDOMNodeActivated(const DOM::Node &node)
   } // end of Anchor tags. 
 }
 
-void KitaThreadView::slotShowThread(const KURL& _datURL, const KURL& _boardURL, const QString& boardName)
+//void KitaThreadView::slotShowThread(const KURL& _datURL, const KURL& _boardURL, const QString& boardName)
+void KitaThreadView::slotShowThread(const Kita2ch::Board& board, const Kita2ch::Thread& thread)
 {
   { //reset member variables associated with a thread.
     m_prevquery = "";
@@ -133,23 +136,18 @@ void KitaThreadView::slotShowThread(const KURL& _datURL, const KURL& _boardURL,
     m_hitcount = 0;
     m_writeResult = "";
     m_threadData = "";
-    m_subject = "";
-    m_contentsBody = DOM::HTMLBodyElement();
+    m_contents = "";
     m_pointStack.clear();
   }
 
-  if ( _datURL.protocol() != "k2ch" ) { 
-    KIO::SlaveConfig::self()->setConfigData("http", _datURL.host() ,
-                                          "UserAgent", "Monazilla/1.00 (test)");
+  m_board = board;
+  m_thread = thread;
+  if ( m_thread.datURL().protocol() != "k2ch" ) { 
+    KIO::SlaveConfig::self()->setConfigData("http", m_thread.datURL().host() ,
+                                          "UserAgent", "Monazilla/1.00 (Kita/0.3)");
   }
-  m_datURL = _datURL;
-  m_boardURL = _boardURL;
-  m_boardID = m_boardURL.fileName();
-  m_datName = m_datURL.fileName().section('.', 0, 0);
-  m_threadURL = KURL(m_boardURL, QString("../test/read.cgi/") + QString(m_boardURL.filename()) + QString("/") + QString( m_datURL.filename().section('.',0) ) );
-  m_boardName = boardName;
-
-  KIO::TransferJob* job = KIO::get(m_datURL, true, true);
+    
+  KIO::TransferJob* job = KIO::get(m_thread.datURL(), true, true);
   m_currentJob = job;
 
   connect(job, SIGNAL(data(KIO::Job*, const QByteArray&)),
@@ -164,7 +162,7 @@ void KitaThreadView::slotShowThread(const KURL& _datURL, const KURL& _boardURL,
 void KitaThreadView::slotRedirection(KIO::Job *, const KURL & newURL)
 {
   printf("  Redirected to newURL: %s\n", newURL.url().latin1() );
-  m_datURL = newURL;
+  m_thread = Kita2ch::Thread(newURL);
   emit setLocationBarURL(newURL.url());
 }
 
@@ -174,6 +172,26 @@ void KitaThreadView::slotReceiveThreadData(KIO::Job*, const QByteArray& data)
   m_threadData.append(cstr);
 }
 
+int KitaThreadView::getServerTimeFromHttpHeaders(QString headers)
+{
+  // parse HTTP headers
+  QStringList headerList = QStringList::split("\n", headers);
+  QRegExp regexp("Date: (...), (..) (...) (....) (..:..:..) .*");
+  QString dateStr = headerList.grep(regexp)[0];
+  if(regexp.search(dateStr) == -1) {
+    // invalid date format
+    return time(NULL);
+  } else {
+    // I hate this format ;p
+    QString usLocalDateStr = regexp.cap(1) + " " + regexp.cap(3) + " " +
+                             regexp.cap(2) + " " + regexp.cap(5) + " " + regexp.cap(4);
+
+    // 1970/01/01 00:00:00 GMT
+    QDateTime zeroTime(QDate(1970, 1, 1), QTime(0, 0));
+    return zeroTime.secsTo(QDateTime::fromString(usLocalDateStr));
+  }
+}
+
 void KitaThreadView::slotThreadResult(KIO::Job* job)
 {
   m_currentJob = 0;
@@ -187,24 +205,9 @@ void KitaThreadView::slotThreadResult(KIO::Job* job)
   stream.setCodec(&codec);
   QString line;
   QString text;
-  int num = 1;
+  int num = 0;
 
-  // parse HTTP headers
-  QStringList headerList = QStringList::split("\n", job->queryMetaData("HTTP-Headers"));
-  QRegExp regexp("Date: (...), (..) (...) (....) (..:..:..) .*");
-  QString dateStr = headerList.grep(regexp)[0];
-  if(regexp.search(dateStr) == -1) {
-    // invalid date format
-    serverTime = time(NULL);
-  } else {
-    // I hate this format ;p
-    QString usLocalDateStr = regexp.cap(1) + " " + regexp.cap(3) + " " +
-                             regexp.cap(2) + " " + regexp.cap(5) + " " + regexp.cap(4);
-
-    // 1970/01/01 00:00:00 GMT
-    QDateTime zeroTime(QDate(1970, 1, 1), QTime(0, 0));
-    serverTime = zeroTime.secsTo(QDateTime::fromString(usLocalDateStr));
-  }
+  m_serverTime = getServerTimeFromHttpHeaders(job->queryMetaData("HTTP-Headers"));
 
   int total = m_threadData.length();
   int step = 0;
@@ -214,60 +217,41 @@ void KitaThreadView::slotThreadResult(KIO::Job* job)
   progress->setTotalSteps( static_cast<int>(total * 0.7) );
   progress->setLabelText( "Parse DAT file.....");
   progress->show();
+  
+  text += "<html><head>";
+  text += "</head><body>";
   while(!stream.atEnd()) {
+    
     line = stream.readLine();
-    QStringList list = QStringList::split("<>", line, true);
-
-    if(list.size() != 5) {
-      // probably eof
-      break;
+    Kita2ch::Comment comment(line);
+    if( comment.isValid() == false) {
+      continue;
     }
-    QString name = list[0];
-    QString address = list[1];
-    QString dateId = list[2];
-    QString body = list[3];
-    QString subject = list[4];
-
-    if(num == 1) {
-      m_subject = subject;
-      {
-	QString disp( m_subject );
-	if ( ! m_boardName.isEmpty() ) { disp.prepend( QString("[%1]").arg(m_boardName) ); }
-	disp.truncate( m_labelMaxLength );
-	subjectLabel->setText( disp );
-      }
-      text += "<html><head>";
-      text += "</head><body>";
-    }
-    text += "<dl><dt>";
-    text += "<span id=\"";
-    text += QString::number(num);
-    text += "\"/>";
-    text += QString::number(num);
-    text += " ";
-    if(address != "") {
-      text += "<a href='mailto:" + address + "' title='" + address + "'>" + name + "</a>";
-    } else {
-      text += name;
-    }
-    text += " ";
-    text += dateId;
-    text += "</dt><dd>";
-    text += linkURL(body);
-    text += "<br/><br/></dd></dl>"; // Using '/>' is Recommended for performance reasons.
 
     num++;
+    if(num == 1) {
+      m_thread.setName(comment.getSubject());
+    }
+    text += comment.toHtml(num);
+
     if( (step+=line.length()) > next ) {
       progress->setProgress( step );
       next += divide;
     }
   }
   delete progress;
-  m_rescount = num - 1;
+  
+  m_thread.setResNum(num);
+  emit setVestedNum(m_thread.datURL(), m_thread.resNum());
 
+  QString disp( m_thread.name() );
+  if ( ! m_board.name().isEmpty() ) { disp.prepend( QString("[%1]").arg(m_board.name()) ); }
+  disp.truncate( m_labelMaxLength );
+  subjectLabel->setText( disp );
+  
   {
     int target;
-    for ( target = 1; target < m_rescount; target += 100 )
+    for ( target = 1; target < m_thread.resNum(); target += 100 )
       text += QString(" <a href=\"#%1\">%3</a> ").arg(target).arg(target);
     text += "<br/>";
   }
@@ -275,22 +259,22 @@ void KitaThreadView::slotThreadResult(KIO::Job* job)
   text += QString("<a href=\"%1#%2\">check new one.</a>").arg( m_datURL.url() ).arg( m_rescount );
 #endif
   text += "</body></html>";
+  m_contents = text;
 
-  slotDisplayContents(text, m_datURL );
+  slotDisplayContents( m_contents, m_thread.datURL() );
   if ( HighLightButton->isOn() ) {
     HighLightButton->toggle();
   }
-  m_contentsBody = threadPart->htmlDocument().body();
   m_threadData.truncate(0);
 
-  if ( m_datURL.hasRef() ) {
-    if ( ! gotoAnchor( m_datURL.encodedHtmlRef()) )
-      gotoAnchor( m_datURL.htmlRef() );
+  if ( m_thread.datURL().hasRef() ) {
+    if ( ! gotoAnchor( m_thread.datURL().encodedHtmlRef()) )
+      gotoAnchor( m_thread.datURL().htmlRef() );
   } else {
-    gotoAnchor( QString().setNum(m_rescount) );
+    gotoAnchor( QString().setNum(m_thread.resNum() - 1) );
   }
   m_pointStack.clear();
-  KHTMLView * view = threadPart->view();
+  KHTMLView * view = m_threadPart->view();
   m_pointStack.push( QPoint( view->contentsX(), view->contentsY() ) );
 
   emit showThreadCompleted();
@@ -299,9 +283,9 @@ void KitaThreadView::slotThreadResult(KIO::Job* job)
 void KitaThreadView::slotDisplayContents(const QString& input, const KURL& url)
 {
   printf("    begin Display: %s\n", url.url().latin1() );
-  threadPart->begin( url );
-  threadPart->write( input );
-  threadPart->end();
+  m_threadPart->begin( url );
+  m_threadPart->write( input );
+  m_threadPart->end();
   if ( ! url.isEmpty() ) emit setLocationBarURL(url.url());
 }
 
@@ -310,51 +294,18 @@ void KitaThreadView::slotWriteButtonClicked()
   KitaWriteDialog dialog;
 
   QSjisCodec cp932Codec;
-  KURL bbscgiURL = KURL(m_boardURL, "../test/bbs.cgi");
+  KURL bbscgiURL = KURL(m_board.url(), "../test/bbs.cgi");
   bbscgiURL.setProtocol( "http" );
 
   KitaWriteDialog::PostInfo info;
   info.host = bbscgiURL.host();
-  info.bbs = m_boardID;
-  info.key = m_datName;
-  info.time = QString("%1").arg(serverTime);
+  info.bbs = m_board.id();
+  info.key = m_thread.datID();
+  info.time = QString("%1").arg(m_serverTime);
   QDialog * new_dialog = KitaWriteDialog::open( info );
   connect( new_dialog, SIGNAL( postResponse(const QString&, const KURL&) ),
       	   this, SLOT( slotDisplayContents(const QString&, const KURL&) ) );
   new_dialog->show(); //work asynchronus.
-
-#if 0
-  if(dialog.exec() != QDialog::Accepted)
-    return;
-
-  QString postStr;
-  int cp932MIB = cp932Codec.mibEnum();
-  QTextStream stream(&postStr, IO_WriteOnly);
-  QString name = KURL::encode_string(dialog.name(), cp932MIB);
-  QString mail = KURL::encode_string(dialog.mail(), cp932MIB);
-  QString body = KURL::encode_string(dialog.body(), cp932MIB);
-
-  stream << "submit=%91%53%90%d3%94%43%82%f0%95%89%82%a4%82%b1%82%c6"; // zennsekininnwooukoto
-  stream << "%82%f0%8f%b3%91%f8%82%b5%82%c4%8f%91%82%ab%8d%9e%82%de&"; // wosyoudakusitekakikomu
-  stream << "subject=&";
-  stream << "FROM=" << name << "&";
-  stream << "mail=" << mail << "&";
-  stream << "MESSAGE=" << body << "&";
-  stream << "bbs=" << m_boardID << "&";
-  stream << "key=" << m_datName << "&";
-  stream << "time=" << serverTime;
-
-  KIO::TransferJob* job = KIO::http_post(bbscgiURL, postStr.utf8(), true);
-
-  // see kdelibs/kioslave/http/http.cc:2216
-  job->addMetaData("content-type", "Content-type: application/x-www-form-urlencoded");
-
-  job->addMetaData("referrer", KURL(m_boardURL,"./index2.html").prettyURL());
-
-  connect(job, SIGNAL(data(KIO::Job*, const QByteArray&)),
-          SLOT(slotReceiveWriteResult(KIO::Job*, const QByteArray&)));
-  connect(job, SIGNAL(result(KIO::Job*)), SLOT(slotWriteResult(KIO::Job*)));
-#endif
 }
 
 void KitaThreadView::slotReceiveWriteResult(KIO::Job *,  const QByteArray & data)
@@ -372,9 +323,9 @@ void KitaThreadView::slotWriteResult(KIO::Job* job)
     QTextStream stream(m_writeResult, IO_ReadOnly);
     stream.setCodec(&codec);
 
-    threadPart->begin();
-    threadPart->write( m_writeResult.data(), m_writeResult.size() );
-    threadPart->end();
+    m_threadPart->begin();
+    m_threadPart->write( m_writeResult.data(), m_writeResult.size() );
+    m_threadPart->end();
     qDebug("#%s#", (const char *)stream.read().local8Bit());
     m_writeResult.truncate(0);
   }
@@ -419,7 +370,7 @@ QStringList KitaThreadView::parseSearchQuery(const QString &input)
   QRegExp truncSpace("\\s*$");
   QStringList::iterator it = tmp.begin();
   for( ; it != tmp.end(); ++it )
-    ret_list += (*it).remove( truncSpace );
+    ret_list += (*it).replace( truncSpace, "" );
   return ret_list;
 }
 
@@ -438,7 +389,7 @@ void KitaThreadView::searchNext(const QStringList &query)
     return;
   }
     
-  gotoAnchor( QString("highlight%1").arg(m_nextHit)  );
+  gotoAnchor( QString("highlighten%1").arg(m_nextHit)  );
   ++m_nextHit;
   if ( !( m_nextHit < m_hitcount ) ) m_nextHit = 0;
 }
@@ -446,31 +397,31 @@ void KitaThreadView::searchNext(const QStringList &query)
 void KitaThreadView::highLighten(bool yes, const QStringList &query)
 {
   if ( ! yes ) {
-    threadPart->setUserStyleSheet( QString("") );
+    m_threadPart->setUserStyleSheet( QString("") );
     return;
   }
 
   // Use style sheet to highlighten.
   QString highlightCSS( ".highlight { color: %1; background: %2; } ");
 #if 0
-  QColorGroup cg = threadPart->view()->colorGroup();
+  QColorGroup cg = m_threadPart->view()->colorGroup();
   highlightCSS = highlightCSS.arg( cg.highlightedText().name() ).arg( cg.highlight().name()  );
 #else
   highlightCSS = highlightCSS.arg( "yellow" ).arg( "black" );
 #endif
-  threadPart->setUserStyleSheet( highlightCSS );
+  m_threadPart->setUserStyleSheet( highlightCSS );
   
 
   if ( m_prevquery == query ) return;
   m_prevquery = query;
   if ( query.isEmpty() ) return;
 
-  threadPart->htmlDocument().setBody( m_contentsBody );
+  slotDisplayContents( m_contents, m_thread.datURL() );
   DOM::NodeList nodes;
   m_hitcount = 0;
-  nodes = threadPart->document().getElementsByTagName("body");
+  nodes = m_threadPart->document().getElementsByTagName("body");
   highLightenNodes( nodes, query );
-  threadPart->setUserStyleSheet( highlightCSS );
+  m_threadPart->setUserStyleSheet( highlightCSS );
 }
 
 QStringList KitaThreadView::lt_gt_spliter( const QString & input )
@@ -521,7 +472,9 @@ void KitaThreadView::highLightenNodes(DOM::NodeList nodes, const QStringList &qu
 	if( message.at(0) == '<' ) continue;
 	while ( (pos = (*it_msg).find(*it, pos)) != -1 ) {
 	  //QMessageBox::information( 0, "Hit!",  QString( "pos: %1 (length: %2)\nhitcount: %4\nstring:\n%3").arg(pos).arg((*it).length()).arg(message).arg(m_hitcount) );
-	  QString replace = QString("<font class=\"highlight\" id=\"highlight%2\">%1</font>").arg(*it).arg( m_hitcount );
+	  QString replace = QString("<font class=\"highlight\" id=\"highlighten%2\">").arg( m_hitcount );
+	  replace += *it;
+	  replace += "</font>";
 	  message.replace(pos, (*it).length(), replace);
 	  //printf("dd %d: replaced:: %s\n", count, message.latin1() );
 	  pos += replace.length();
@@ -547,43 +500,18 @@ void KitaThreadView::slotOnURL(const QString& url)
   emit signalChangeStatusbar(url);
 }
 
-static QString linkURL(QString str)
-{
-  QString ret;
-  // see RFC 1738.
-  QRegExp url_rx("(h?ttp://([-.0-9a-zA-Z]+(/[;:@&=$-_.+!*'(),%~/?#0-9a-zA-Z]*)?))");
-  
-  int i;
-  while ((i = str.find(url_rx)) != -1) {
-    if (i == 0) {
-      // starts with URL.
-      ret += "<a href='http://";
-      ret += url_rx.cap(2);
-      ret += "'>";
-      ret += url_rx.cap(1);
-      ret += "</a>";
-      str.remove(0, url_rx.cap(1).length());
-    } else {
-      ret += str.left(i);
-      str.remove(0, i);
-    }
-  }
-  ret += str;
-  return ret;
-}
-
 bool KitaThreadView::gotoAnchor( const QString &name )
 {
-  KHTMLView * view = threadPart->view();
+  KHTMLView * view = m_threadPart->view();
   m_pointStack.push( QPoint( view->contentsX(), view->contentsY() ) );
-  return threadPart->gotoAnchor( name );
+  return m_threadPart->gotoAnchor( name );
 }
 
 bool KitaThreadView::gobackAnchor()
 {
   QPoint p = m_pointStack.pop();
   if ( m_pointStack.isEmpty() ) m_pointStack.push( p );
-  threadPart->view()->setContentsPos( p.x(), p.y()  );
+  m_threadPart->view()->setContentsPos( p.x(), p.y()  );
   return true;
 }
 
@@ -604,20 +532,25 @@ void KitaThreadView::slotOpenURLRequest(const KURL& url, const KParts::URLArgs&
     return;
   }
   KURL datURL = filterReadCGI( url );
-  if ( datURL.host() == m_datURL.host()
-    && datURL.path() == m_datURL.path() )
+  if ( datURL.host() == m_thread.datURL().host()
+    && datURL.path() == m_thread.datURL().path() )
   {
     if ( datURL.hasRef() ) gotoAnchor( datURL.ref() );
     return;
   }
   emit openURLRequest(datURL, args);
 }
+
+void KitaThreadView::slotReloadButton()
+{
+  slotShowThread(m_board, m_thread);
+}
     
 KURL KitaThreadView::filterReadCGI(const KURL& url)
 {
   KURL  newURL = url;
   if ( url.path().contains("/test/read.cgi") ) {
-    newURL.setProtocol( m_datURL.protocol() );
+    newURL.setProtocol( m_thread.datURL().protocol() );
     QString tmp = url.path().section("/test/read.cgi", 1);
     //printf("    tmp: %s\n", tmp.latin1() );
 
@@ -638,4 +571,9 @@ KURL KitaThreadView::filterReadCGI(const KURL& url)
   printf("    newURL: %s\n", newURL.url().latin1() );
   return newURL;
 }
+
+void KitaThreadView::slotFontChanged(QFont& font)
+{
+  m_threadPart->setStandardFont(font.family());
+}
 // vim:sw=2:
