@@ -5,9 +5,13 @@
 #include "pref.h"
 
 #include <klocale.h>
+#include <kfontdialog.h>
 
 #include <qlayout.h>
 #include <qlabel.h>
+#include <qpushbutton.h>
+
+#include "kitafontprefbase.h"
 
 KitaPreferences::KitaPreferences()
     : KDialogBase(TreeList, i18n("Kita Preferences"),
@@ -17,20 +21,29 @@ KitaPreferences::KitaPreferences()
     // a Treelist dialog.. but there are a number of other
     // possibilities (including Tab, Swallow, and just Plain)
     QFrame *frame;
-    frame = addPage(i18n("First Page"), i18n("Page One Options"));
-    m_pageOne = new KitaPrefPageOne(frame);
+    frame = addPage(i18n("Font"), i18n("Font"));
+    m_fontPage = new KitaFontPrefPage(frame);
 
-    frame = addPage(i18n("Second Page"), i18n("Page Two Options"));
-    m_pageTwo = new KitaPrefPageTwo(frame);
+//    frame = addPage(i18n("Second Page"), i18n("Page Two Options"));
+//    m_pageTwo = new KitaPrefPageTwo(frame);
+    
+    connect(m_fontPage, SIGNAL(signalFontChanged(QFont&)), SIGNAL(signalFontChanged(QFont&)));
 }
 
-KitaPrefPageOne::KitaPrefPageOne(QWidget *parent)
-    : QFrame(parent)
+KitaFontPrefPage::KitaFontPrefPage(QWidget *parent)
+    : KitaFontPrefBase(parent)
 {
-    QHBoxLayout *layout = new QHBoxLayout(this);
-    layout->setAutoAdd(true);
+  connect(fontButton, SIGNAL(clicked()), SLOT(slotFontButtonClicked()));
+}
 
-    new QLabel(i18n("Add something here"), this);
+void KitaFontPrefPage::slotFontButtonClicked()
+{
+  QFont font;
+
+  if( KFontDialog::getFont(font, false, this) == QDialog::Accepted ) {
+    fontButton->setText(font.family());
+    emit signalFontChanged(font);
+  }
 }
 
 KitaPrefPageTwo::KitaPrefPageTwo(QWidget *parent)
